@@ -24,11 +24,7 @@ describe 'freezer::client' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
-            { :client_package_name => 'python3-freezerclient' }
-          else
-            { :client_package_name => 'python-freezerclient' }
-          end
+          { :client_package_name => 'python3-freezerclient' }
         when 'RedHat'
           { :client_package_name => 'python-freezerclient' }
         end
